FileBlockDevice

Struct FileBlockDevice 

pub struct FileBlockDevice { /* private fields */ }
A block device backed by a file on the host filesystem.

This is useful for working with disk images or loopback devices.

Implementations

Source

impl FileBlockDevice

pub fn create<P: AsRef<Path>>(path: P, size: u64) -> Result<Self>

Create a new disk image file with the specified size.

Arguments
  • path - Path to create the file at
  • size - Total size in bytes
  • block_size - Block size (default 512)
Returns

A new FileBlockDevice wrapping the created file

pub fn create_with_block_size<P: AsRef<Path>>( path: P, size: u64, block_size: u32, ) -> Result<Self>

Create a new disk image file with custom block size.

pub fn open<P: AsRef<Path>>(path: P) -> Result<Self>

Open an existing disk image file.

Arguments
  • path - Path to the file
Returns

A FileBlockDevice wrapping the file

pub fn open_with_block_size<P: AsRef<Path>>( path: P, block_size: u32, ) -> Result<Self>

Open an existing disk image file with custom block size.

pub fn open_read_only<P: AsRef<Path>>(path: P) -> Result<Self>

Open an existing disk image file in read-only mode.

pub fn open_read_only_with_block_size<P: AsRef<Path>>( path: P, block_size: u32, ) -> Result<Self>

Open an existing disk image file in read-only mode with custom block size.