pub struct FileBlockDevice { /* private fields */ }Expand description
A block device backed by a file on the host filesystem.
This is useful for working with disk images or loopback devices.
Implementations
Sourceimpl FileBlockDevice
impl FileBlockDevice
Sourcepub fn create_with_block_size<P: AsRef<Path>>(
path: P,
size: u64,
block_size: u32,
) -> Result<Self>
pub fn create_with_block_size<P: AsRef<Path>>( path: P, size: u64, block_size: u32, ) -> Result<Self>
Create a new disk image file with custom block size.
Sourcepub fn open_with_block_size<P: AsRef<Path>>(
path: P,
block_size: u32,
) -> Result<Self>
pub fn open_with_block_size<P: AsRef<Path>>( path: P, block_size: u32, ) -> Result<Self>
Open an existing disk image file with custom block size.
Sourcepub fn open_read_only<P: AsRef<Path>>(path: P) -> Result<Self>
pub fn open_read_only<P: AsRef<Path>>(path: P) -> Result<Self>
Open an existing disk image file in read-only mode.